@@ -63,7 +63,8 @@ def sampling_rate_consistency(record):
     for sampling_rate in sampling_trunc:
         if (sampling_rate!=sampling_mode):
             abnormal_sampling_gap_count += 1
-    return 1-(abnormal_sampling_gap_count/total_sampling_gap)
+    SRC = 1-(abnormal_sampling_gap_count/total_sampling_gap)
+    return SRC
 
 
 def count_missing_segments(record, sample_mode):
